@@ -1,9 +1,9 @@
-# Copyright 2000 - 2013 NeuStar, Inc.All rights reserved.
-# NeuStar, the Neustar logo and related names and logos are registered
-# trademarks, service marks or tradenames of NeuStar, Inc. All other
+# Copyright 2023 Vercara. All rights reserved.
+# Vercara, the Vercara logo and related names and logos are registered
+# trademarks, service marks or tradenames of Vercara. All other
 # product names, company names, marks, logos and symbols may be trademarks
 # of their respective owners.
-__author__ = 'Jon Bodner'
+__author__ = 'UltraDNS'
 from .connection import RestApiConnection
 import json
 import time
